==> pgadmin4-7.8.tar.gz: pgadmin4-7.8/web/pgadmin/tools/import_export_servers/static/js/import_export_servers.js <==
/////////////////////////////////////////////////////////////
//
// pgAdmin 4 - PostgreSQL Tools
//
// Copyright (C) 2013 - 2023, The pgAdmin Development Team
// This software is released under the PostgreSQL Licence
//
//////////////////////////////////////////////////////////////

import React from 'react';
import ReactDOM from 'react-dom';
import gettext from 'sources/gettext';
import Theme from 'sources/Theme';
import ImportExportServers from './ImportExportServers';
import pgBrowser from 'top/browser/static/js/browser';

export default class ImportExportServersModule {
  static instance;

  static getInstance(...args) {
    if(!ImportExportServersModule.instance) {
      ImportExportServersModule.instance = new ImportExportServersModule(...args);
    }
    return ImportExportServersModule.instance;
  }

  init() {
    if (this.initialized)
      return;
    this.initialized = true;

    // Define the nodes on which the menus to be appear
    let menus = [{
      name: 'import_export_servers',
      module: this,
      applies: ['tools'],
      callback: 'showImportExportServers',
      enable: true,
      priority: 3,
      label: gettext('Import/Export Servers...'),
    }];

    pgBrowser.add_menus(menus);
  }

  // This is a callback function to show import/export servers when user click on menu item.
  showImportExportServers() {
    // Register dialog panel
    pgBrowser.Node.registerUtilityPanel();
    let panel = pgBrowser.Node.addUtilityPanel(880, 550),
      j = panel.$container.find('.obj_properties').first();
    panel.title(gettext('Import/Export Servers'));

    ReactDOM.render(
      <Theme>
        <ImportExportServers
          onClose={() => {
            ReactDOM.unmountComponentAtNode(j[0]);
            panel.close();
          }}/>
      </Theme>, j[0]);
  }
}

==> pgadmin4-9.2.tar.gz: pgadmin4-9.2/web/pgadmin/tools/import_export_servers/static/js/import_export_servers.js <==
/////////////////////////////////////////////////////////////
//
// pgAdmin 4 - PostgreSQL Tools
//
// Copyright (C) 2013 - 2025, The pgAdmin Development Team
// This software is released under the PostgreSQL Licence
//
//////////////////////////////////////////////////////////////

import React from 'react';
import gettext from 'sources/gettext';
import ImportExportServers from './ImportExportServers';
import { BROWSER_PANELS } from '../../../../browser/static/js/constants';
import pgAdmin from 'sources/pgadmin';
import { isDefaultWorkspace } from '../../../../static/js/utils';

export default class ImportExportServersModule {
  static instance;

  static getInstance(...args) {
    if(!ImportExportServersModule.instance) {
      ImportExportServersModule.instance = new ImportExportServersModule(...args);
    }
    return ImportExportServersModule.instance;
  }

  init() {
    if (this.initialized)
      return;
    this.initialized = true;

    // Define the nodes on which the menus to be appear
    let menus = [{
      name: 'import_export_servers',
      module: this,
      applies: ['tools'],
      callback: 'showImportExportServers',
      enable: isDefaultWorkspace,
      priority: 3,
      label: gettext('Import/Export Servers...'),
    }];

    pgAdmin.Browser.add_menus(menus);
  }

  // This is a callback function to show import/export servers when user click on menu item.
  showImportExportServers() {
    const panelTitle = gettext('Import/Export Servers');
    const panelId = BROWSER_PANELS.IMPORT_EXPORT_SERVERS;
    pgAdmin.Browser.docker.default_workspace.openDialog({
      id: panelId,
      title: panelTitle,
      manualClose: false,
      content: (
        <ImportExportServers onClose={()=>{pgAdmin.Browser.docker.default_workspace.close(panelId);}}/>
      )
    }, pgAdmin.Browser.stdW.lg, pgAdmin.Browser.stdH.lg);
  }
}
